Learn R Programming

cdid (version 0.1.0)

gmm_convert_result: GMM_convert_result

Description

Function to convert results so they can be used by the did package developed by Brantly Callaway. For more details on the methodology, see: Bellego, Benatia, and Dortet-Bernadet (2024), "The Chained Difference-in-Differences", Journal of Econometrics, https://doi.org/10.1016/j.jeconom.2023.11.002.

Usage

gmm_convert_result(dp, type)

Value

a DIDparams object

Arguments

dp

a dp object

type

1 for 2step weighting, 2 for identity weighting